pocketpose.summarize_models - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.summarize_models`

## Module Contents

### Functions

`parse_args`() |
`list_models`(models_dir) | List all TFLite models in a folder.
`main`() |

pocketpose.summarize_models.parse_args()

pocketpose.summarize_models.list_models(models_dir: str)

  List all TFLite models in a folder.

pocketpose.summarize_models.main()